@@ -35,7 +35,8 @@ void usage(void)
 	printf("-R interval    same as -r, only with this one only the difference is displayed\n");
 	printf("-Rc/-rc interval  like -r/-R but clean the window before each iteration\n");
 	printf("--cont         reconnect lines with a '\' at the end\n");
-	printf("--mergeall     merge all of the following files into the same window\n");
+	printf("--mergeall     merge all of the following files into the same window (in the previous window)\n");
+	printf("--mergeall-new merge all of the following files into the same window (in a new window)\n");
 	printf("--no-mergeall  stop merging all files into one window\n");
 	printf("--no-repeat    suppress repeating lines and replace them with a \"last message repeated x times\"\n");
 	printf("--mark-interval x	when nothing comes in, print a '---mark---' line every 'x' seconds\n");
@@ -469,6 +470,7 @@ void do_commandline(int argc, char *argv[])
 	redirect_t *predir = NULL;
 	mybool_t used_stdin = MY_FALSE;
 	char merge_all = 0;
+	char merge_in_new_first = 0;
 	int close_idle = 0;
 	char setallmaxbytes = 0;
 	int maxbytes = -1;
@@ -555,6 +557,12 @@ void do_commandline(int argc, char *argv[])
 		else if (strcmp(argv[loop], "--mergeall") == 0)
 		{
 			merge_all = 1;
+			merge_in_new_first = 0;
+		}
+		else if (strcmp(argv[loop], "--mergeall-new") == 0)
+		{
+			merge_all = 1;
+			merge_in_new_first = 1;
 		}
 		else if (strcmp(argv[loop], "--no-mergeall") == 0)
 		{
@@ -819,6 +827,12 @@ void do_commandline(int argc, char *argv[])
 					merge_all)
 			{
 				is_sub = 1;
+
+				if (merge_all & (merge_in_new_first == 1))
+				{
+					is_sub = 0;
+					merge_in_new_first = 0;
+				}
 			}
 
 			if (argv[loop][0] == '-' && toupper(argv[loop][1]) != 'J')
