@@ -384,6 +384,7 @@ void scrollback_do(int window_nr, buffer *pbuf, int *winnrs, char *header)
 				&& offset < (pbuf -> curpos - 1))
 		{
 			int dummy = 0;
+			int lines = 0;
 			int page_size = (c == 'u' || c == ('U' - 65 + 1)) ? (nlines / 2) : nlines;
 			while(offset < (pbuf -> curpos - 1))
 			{
@@ -391,9 +392,12 @@ void scrollback_do(int window_nr, buffer *pbuf, int *winnrs, char *header)
 				dummy += get_lines_needed((pbuf -> be)[offset].Bline, ncols);
 				if (dummy > page_size && c == KEY_NPAGE)
 				{
-					offset--;
+					if (lines > 0)
+						offset--;
 					break;
 				}
+
+				lines++;
 			}
 			redraw = 2;
 		}
@@ -406,6 +410,7 @@ void scrollback_do(int window_nr, buffer *pbuf, int *winnrs, char *header)
 				&& offset > 0)
 		{
 			int dummy = 0;
+			int lines = 0;
 			int page_size = (c == 'd' || c == 4) ? (nlines / 2) : nlines;
 			while(offset > 0)
 			{
@@ -413,9 +418,12 @@ void scrollback_do(int window_nr, buffer *pbuf, int *winnrs, char *header)
 				dummy += get_lines_needed((pbuf -> be)[offset].Bline, ncols);
 				if (dummy > page_size)
 				{
-					offset++;
+					if (lines > 0)
+						offset++;
 					break;
 				}
+
+				lines++;
 			}
 			redraw = 2;
 		}
@@ -426,6 +434,7 @@ void scrollback_do(int window_nr, buffer *pbuf, int *winnrs, char *header)
 				&& offset > 0)
 		{
 			line_offset = offset = 0;
+			redraw = 2;
 		}
 		else if ((c == KEY_END ||
 			  c == 'G' ||
@@ -434,6 +443,7 @@ void scrollback_do(int window_nr, buffer *pbuf, int *winnrs, char *header)
 				&& offset < (pbuf -> curpos - 1))
 		{
 			offset = pbuf -> curpos - 1;
+			redraw = 2;
 		}
 		else if (uc == 'R' || c == ('R' - 65 + 1) || c == ('L' - 65 + 1) || c == KEY_REFRESH)
 		{
