@@ -101,7 +101,7 @@ void edit_color(int index)
 		escape_print(mywin, 12, 2, "^b^   edit blue");
 		escape_print(mywin, 13, 2, "^c^   change colorname");
 		mvwprintw(mywin -> win, 14, 2, "Press ^g to exit this screen");
-		box(mywin -> win, 0, 0);
+		wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 		mydoupdate();
 
 		c = wait_for_keypress(HELP_EDIT_COLOR, 0, mywin, 1);
@@ -256,7 +256,7 @@ int color_management(myattr_t *org, myattr_t *new)
 			}
 		}
 
-		box(mywin -> win, 0, 0);
+		wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 		wmove(mywin -> win, 3 + cursor_y, 3 + cursor_x * 20);
 		mydoupdate();
 
@@ -574,11 +574,14 @@ int select_schemes(void *schemes_in, int n_schemes_in, scheme_t tscheme, int_arr
 {
 	NEWWIN *win;
 	int loop, cur_offset = 0, cur_line = 0;
-	char *selected_schemes;
+	char *selected_schemes = NULL;
 	int c = 0;
 
 	if (n_schemes_in == 0)
+	{
 		error_popup("Error selecting schemes", -1, "Cannot select %s schemes: none defined in configuration file!", tscheme == SCHEME_COLOR?"color":"conversion");
+		return -1;
+	}
 
 	/* create array that says for each colorscheme if it is selected or not */
 	selected_schemes = (char *)mymalloc(n_schemes_in, "select_schemes: selected schemes");
@@ -616,7 +619,7 @@ int select_schemes(void *schemes_in, int n_schemes_in, scheme_t tscheme, int_arr
 			mvwprintw(win -> win, 3 + loop, 2, "[%c] %s", selected_schemes[cur_offset + loop]?'X':' ', name);
 			if (loop == cur_line) ui_inverse_off(win);
 		}
-		box(win -> win, 0, 0);
+		wborder(win -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 		mydoupdate();
 
 		c = toupper(wait_for_keypress(tscheme == SCHEME_COLOR ? HELP_SELECT_COLORSCHEMES : HELP_SELECT_CONVERSIONSCHEMES, 0, win, 1));
@@ -836,7 +839,7 @@ char ask_colors(NEWWIN *win, int line, char cur, char *fieldnr, char **fielddel,
 				break;
 
 			case 13:
-				if (cur != -1)
+				if (cur != (char)-1)
 					return cur;
 
 			default:
@@ -1052,7 +1055,7 @@ int add_window(void)
 			break;
 
 		werase(mywin -> win);
-		box(mywin -> win, 0, 0);
+		wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 	}
 
 	delete_popup(mywin);
@@ -1088,7 +1091,7 @@ int toggle_colors(void)
 			mvwprintw(mywin -> win, 3, 1, dummy);
 
 			col = ask_colors(mywin, 4, cur -> cdef.colorize, &cur -> cdef.field_nr, &cur -> cdef.field_del, &cur -> cdef.color_schemes, &cur -> cdef.attributes, &cur -> cdef.term_emul);
-			if (col != -1)
+			if (col != (char)-1)
 			{
 				changed = 1;
 				cur -> cdef.colorize = col;
@@ -1171,7 +1174,7 @@ int edit_regexp(void)
 				ui_inverse_off(mywin);
 			mvwprintw(mywin -> win, 4 + loop, 60, "%d", (cur -> pre)[loop].match_count);
 		}
-		box(mywin -> win, 0, 0);
+		wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 		mydoupdate();
 
 		/* wait for key */
@@ -1461,7 +1464,7 @@ void list_keybindings(void)
 				mvwprintw(mywin -> win, 2 + loop, 5, "%s", keybindings[loop + curpos].command);
 			}
 
-			box(mywin -> win, 0, 0);
+			wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 			mydoupdate();
 
 			prevpos = curpos;
@@ -1591,9 +1594,15 @@ void write_script(void)
 			{
 				int lloop;
 
-				if (cur -> check_interval)			
+				if (cur -> beep.beep_interval != -1)
+					fprintf(fh, " --bi %d", cur -> beep.beep_interval);
+
+				if (cur -> check_interval)
 					fprintf(fh, " -iw %d", cur -> check_interval);
 
+				if (cur -> cont)
+					fprintf(fh, " --cont");
+
 				/* terminal emulation */
 				if (cur -> cdef.term_emul == TERM_ANSI)
 					fprintf(fh, " -cT ANSI"); /* vt100 */
@@ -1602,6 +1611,9 @@ void write_script(void)
 				if (cur -> add_timestamp)
 					fprintf(fh, " -ts");
 
+				if (cur -> label)
+					fprintf(fh, " --label %s", cur -> label);
+
 				/* title in statusline */
 				if (cur -> win_title)
 				{
@@ -1792,7 +1804,7 @@ void write_script(void)
 
 		fclose(fh);
 	}
-	else
+	else if (fname != NULL)
 	{
 		error_popup("Write script", HELP_ERROR_WRITE_SCRIPT_CREATE_FILE, "Error creating file: %s", strerror(errno));
 	}
@@ -1820,7 +1832,7 @@ void do_pause(void)
 
 	color_on(mywin, 1);
 	mvwprintw(mywin -> win, 1, 1, "Paused");
-	box(mywin -> win, 0, 0);
+	wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 	color_off(mywin, 1);
 
 	wmove(mywin -> win, 1, 2);
@@ -1972,7 +1984,7 @@ int set_window_widths(void)
 				if (loop == y) ui_inverse_off(mywin);
 			}
 		}
-		box(mywin -> win, 0, 0);
+		wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 		mydoupdate();
 
 		key = toupper(wait_for_keypress(HELP_MANAGE_COLS, 0, mywin, 1));
@@ -2128,7 +2140,7 @@ int set_window_sizes(void)
 		escape_print(mywin, 1, 2, "^m^ manage columns");
 		escape_print(mywin, 2, 2, "^h^ set height of a window");
 		escape_print(mywin, 3, 2, "^q^ quit this menu");
-		box(mywin -> win, 0, 0);
+		wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 		mydoupdate();
 
 		key = toupper(wait_for_keypress(HELP_SET_WINDOWSIZES, 0, mywin, 0));
@@ -2575,7 +2587,7 @@ int send_signal_select_signal(void)
 			if (loop == (cursor_index + 1)) ui_inverse_off(mywin);
 		}
 
-		box(mywin -> win, 0, 0);
+		wborder(mywin -> win, box_left_side, box_right_side, box_top_side, box_bottom_side, box_top_left_hand_corner, box_top_right_hand_corner, box_bottom_left_hand_corner, box_bottom_right_hand_corner);
 		mydoupdate();
 
 		c = toupper(wait_for_keypress(HELP_SELECT_SIGNAL, 0, mywin, 1));
@@ -2841,7 +2853,7 @@ void search_in_all_windows(void)
 
 	mvwprintw(mywin -> win, 3, 2, "^u empty line, ^g abort");
 
-	find = edit_string(mywin, 5, 2, 40, 80, 0, global_find, HELP_SEARCH_IN_ALL_WINDOWS, -1, &search_h, &case_insensitive);
+	find = edit_string(mywin, 5, 2, 40, 80, 0, reuse_searchstring?global_find:NULL, HELP_SEARCH_IN_ALL_WINDOWS, -1, &search_h, &case_insensitive);
 	delete_popup(mywin);
 
 	myfree(global_find);
@@ -2858,7 +2870,7 @@ void highlight_in_all_windows(void)
 	mybool_t case_insensitive = re_case_insensitive;
 
 	win_header(mywin, "Global highlight");
-	find = edit_string(mywin, 3, 2, 40, 80, 0, global_highlight_str, HELP_HIGHLIGHT_IN_ALL_WINDOWS, -1, &search_h, &case_insensitive);
+	find = edit_string(mywin, 3, 2, 40, 80, 0, reuse_searchstring?global_highlight_str:NULL, HELP_HIGHLIGHT_IN_ALL_WINDOWS, -1, &search_h, &case_insensitive);
 	delete_popup(mywin);
 
 	if (global_highlight_str)
